aboutsummaryrefslogtreecommitdiffstats
path: root/boot.php
diff options
context:
space:
mode:
authorFriendika <info@friendika.com>2011-08-07 16:15:54 -0700
committerFriendika <info@friendika.com>2011-08-07 16:15:54 -0700
commit48ffa880f099b19052f18e399bf6af50780a24b0 (patch)
tree48f5e9b52b425af937b5ae2511aaaf6968e0b666 /boot.php
parentaa3a14ec36db5f9df9d0ec27c607a994451fc845 (diff)
downloadvolse-hubzilla-48ffa880f099b19052f18e399bf6af50780a24b0.tar.gz
volse-hubzilla-48ffa880f099b19052f18e399bf6af50780a24b0.tar.bz2
volse-hubzilla-48ffa880f099b19052f18e399bf6af50780a24b0.zip
cleanup
Diffstat (limited to 'boot.php')
-rw-r--r--boot.php26
1 files changed, 15 insertions, 11 deletions
diff --git a/boot.php b/boot.php
index 17161f715..d5adbd7cf 100644
--- a/boot.php
+++ b/boot.php
@@ -7,9 +7,9 @@ require_once('include/text.php');
require_once("include/pgettext.php");
-define ( 'FRIENDIKA_VERSION', '2.2.1063' );
+define ( 'FRIENDIKA_VERSION', '2.2.1065' );
define ( 'DFRN_PROTOCOL_VERSION', '2.21' );
-define ( 'DB_UPDATE_VERSION', 1077 );
+define ( 'DB_UPDATE_VERSION', 1078 );
define ( 'EOL', "<br />\r\n" );
define ( 'ATOM_TIME', 'Y-m-d\TH:i:s\Z' );
@@ -55,13 +55,12 @@ define ( 'REGISTER_OPEN', 2 );
/**
* relationship types
- * When used in contact records, this indicates that 'uid' has
- * this relationship with contact['name']
*/
-define ( 'REL_VIP', 1); // other person is 'following' us
-define ( 'REL_FAN', 2); // we are 'following' other person
-define ( 'REL_BUD', 3); // mutual relationship
+define ( 'CONTACT_IS_FOLLOWER', 1);
+define ( 'CONTACT_IS_SHARING', 2);
+define ( 'CONTACT_IS_FRIEND', 3);
+
/**
* Hook array order
@@ -76,10 +75,10 @@ define ( 'HOOK_FUNCTION', 2);
* page/profile types
*
* PAGE_NORMAL is a typical personal profile account
* PAGE_SOAPBOX automatically approves all friend requests as REL_FAN, (readonly)
* PAGE_COMMUNITY automatically approves all friend requests as REL_FAN, but with
* write access to wall and comments (no email and not included in page owner's ACL lists)
* PAGE_FREELOVE automatically approves all friend requests as full friends (REL_BUD).
*
*/
@@ -283,7 +282,12 @@ class App {
$this->path = $path;
}
- set_include_path("include/$this->hostname" . PATH_SEPARATOR . 'include' . PATH_SEPARATOR . '.' );
+ set_include_path(
+ "include/$this->hostname" . PATH_SEPARATOR
+ . 'include' . PATH_SEPARATOR
+ . 'library' . PATH_SEPARATOR
+ . 'library/phpsec' . PATH_SEPARATOR
+ . '.' );
if((x($_SERVER,'QUERY_STRING')) && substr($_SERVER['QUERY_STRING'],0,2) === "q=")
$this->query_string = substr($_SERVER['QUERY_STRING'],2);
@@ -76,10 +75,10 @@ define ( 'HOOK_FUNCTION', 2);
*
* PAGE_NORMAL is a typical personal profile account
- * PAGE_SOAPBOX automatically approves all friend requests as REL_FAN, (readonly)
- * PAGE_COMMUNITY automatically approves all friend requests as REL_FAN, but with
+ * PAGE_SOAPBOX automatically approves all friend requests as CONTACT_IS_SHARING, (readonly)
+ * PAGE_COMMUNITY automatically approves all friend requests as CONTACT_IS_SHARING, but with
* write access to wall and comments (no email and not included in page owner's ACL lists)
@@ -76,10 +75,10 @@ define ( 'HOOK_FUNCTION', 2);
* write access to wall and comments (no email and not included in page owner's ACL lists)
- * PAGE_FREELOVE automatically approves all friend requests as full friends (REL_BUD).
+ * PAGE_FREELOVE automatically approves all friend requests as full friends (CONTACT_IS_FRIEND).
*
*/